===================
 Invenio-DB v1.0.0
===================

Invenio-DB v1.0.0 was released on October 14, 2015.

About
-----

Database management for Invenio.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-db==1.0.0

Documentation
-------------

   http://pythonhosted.org/invenio-db/

Happy hacking and thanks for flying Invenio-DB.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-db
|   URL: http://invenio-software.org
